==> cdk-cloudfront-plus-0.1.33.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.1.33](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.32...v0.1.33) (2021-04-05)

### [0.1.32](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.31...v0.1.32) (2021-04-05)


### Features

* so8120 multiple origin ip retry ([#58](https://github.com/pahudnet/cdk-cloudfront-plus/issues/58)) ([ceb9bfc](https://github.com/pahudnet/cdk-cloudfront-plus/commit/ceb9bfcf8392d2964867f6c7d745154d180f140a))

### [0.1.31](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.30...v0.1.31) (2021-04-05)

### [0.1.30](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.29...v0.1.30) (2021-04-05)

### [0.1.29](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.28...v0.1.29) (2021-04-04)

### [0.1.28](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.27...v0.1.28) (2021-04-04)


### Features

* **SO8118:** Access Origin by Geolocation ([#52](https://github.com/pahudnet/cdk-cloudfront-plus/issues/52)) ([7eba0e9](https://github.com/pahudnet/cdk-cloudfront-plus/commit/7eba0e939a438b9a0066d4bea65ea00229f00849))

### [0.1.27](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.26...v0.1.27) (2021-04-04)

### [0.1.26](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.25...v0.1.26) (2021-04-03)


### Features

* **extension:** redirect by geolocation  ([#50](https://github.com/pahudnet/cdk-cloudfront-plus/issues/50)) ([012f591](https://github.com/pahudnet/cdk-cloudfront-plus/commit/012f59110be8f450e4b432f607cf49580b8e79f5)), closes [#11](https://github.com/pahudnet/cdk-cloudfront-plus/issues/11)

### [0.1.25](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.24...v0.1.25) (2021-04-03)

### [0.1.24](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.23...v0.1.24) (2021-04-03)


### Bug Fixes

* fix wrong path ([#48](https://github.com/pahudnet/cdk-cloudfront-plus/issues/48)) ([fcd3da3](https://github.com/pahudnet/cdk-cloudfront-plus/commit/fcd3da3cc4b5186ef0f5ea41281513857a3bd5ef))

### [0.1.23](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.22...v0.1.23) (2021-04-03)


### Features

* **ext:** new extension - Redirect to custom error page ([#46](https://github.com/pahudnet/cdk-cloudfront-plus/issues/46)) ([14ffc56](https://github.com/pahudnet/cdk-cloudfront-plus/commit/14ffc564f75900fb7596383d550351ebfd08ba1e))

### [0.1.22](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.21...v0.1.22) (2021-04-03)

### [0.1.21](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.20...v0.1.21) (2021-04-02)

### [0.1.20](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.19...v0.1.20) (2021-04-02)

### [0.1.19](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.18...v0.1.19) (2021-04-01)

### [0.1.18](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.17...v0.1.18) (2021-04-01)

### [0.1.17](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.16...v0.1.17) (2021-04-01)


### Features

* **ext:** new extension - Select origin by viewer country  ([#39](https://github.com/pahudnet/cdk-cloudfront-plus/issues/39)) ([b1b0efd](https://github.com/pahudnet/cdk-cloudfront-plus/commit/b1b0efdfc2b7a5580ffb35fee65ba74008c2bc99))

### [0.1.16](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.15...v0.1.16) (2021-04-01)


### Features

* **extension:** use lambda nodejs replace lambda function  ([#38](https://github.com/pahudnet/cdk-cloudfront-plus/issues/38)) ([b14c745](https://github.com/pahudnet/cdk-cloudfront-plus/commit/b14c74583803e343a8a57cc322b09b24a155acca)), closes [#37](https://github.com/pahudnet/cdk-cloudfront-plus/issues/37)

### [0.1.15](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.14...v0.1.15) (2021-03-31)


### Bug Fixes

* remove src rewrite uri demo.ts ([#35](https://github.com/pahudnet/cdk-cloudfront-plus/issues/35)) ([ab591e7](https://github.com/pahudnet/cdk-cloudfront-plus/commit/ab591e78378406ea278b44943c6271f847c22dca))

### [0.1.14](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.13...v0.1.14) (2021-03-31)

### [0.1.13](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.12...v0.1.13) (2021-03-31)

### [0.1.12](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.11...v0.1.12) (2021-03-30)

### [0.1.11](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.10...v0.1.11) (2021-03-30)


### Features

* add SimpleLambdaEdge extension ([#29](https://github.com/pahudnet/cdk-cloudfront-plus/issues/29)) ([f75f814](https://github.com/pahudnet/cdk-cloudfront-plus/commit/f75f814ed1eba44221ae8545b5350a5f8e9c1a08))

### [0.1.10](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.9...v0.1.10) (2021-03-29)

### [0.1.9](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.8...v0.1.9) (2021-03-29)

### [0.1.8](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.7...v0.1.8) (2021-03-29)

### [0.1.7](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.6...v0.1.7) (2021-03-29)

### [0.1.6](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.5...v0.1.6) (2021-03-29)


### Features

* **extension:** default directory indexes in amazon s3 backed amazon cloudfront origins ([#21](https://github.com/pahudnet/cdk-cloudfront-plus/issues/21)) ([a820391](https://github.com/pahudnet/cdk-cloudfront-plus/commit/a820391383fe0e0336c299b83476f2d30ece2820)), closes [#9](https://github.com/pahudnet/cdk-cloudfront-plus/issues/9)

### [0.1.5](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.4...v0.1.5) (2021-03-28)


### Features

* add-custom-props ([#20](https://github.com/pahudnet/cdk-cloudfront-plus/issues/20)) ([c2915c6](https://github.com/pahudnet/cdk-cloudfront-plus/commit/c2915c6a80655b4fb3685eb45ad07396f4d56d74))

### [0.1.4](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.3...v0.1.4) (2021-03-26)

### [0.1.3](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.2...v0.1.3) (2021-03-22)


### Features

* add security headers extension ([85c5a52](https://github.com/pahudnet/cdk-cloudfront-plus/commit/85c5a52a6dfd4c5a6fac4e480cab251e8e5ac4c6))
* support AntiHotlinking extension ([3bf98d8](https://github.com/pahudnet/cdk-cloudfront-plus/commit/3bf98d8ae42044edb8429fc12ff31e91606cf96e))
* support AntiHotlinking extension ([#2](https://github.com/pahudnet/cdk-cloudfront-plus/issues/2)) ([5d68320](https://github.com/pahudnet/cdk-cloudfront-plus/commit/5d6832019636bc03541b086c4808ea0a3737a603))

### [0.1.2](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.1...v0.1.2) (2021-03-17)

### [0.1.1](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.0...v0.1.1) (2021-03-17)

## 0.1.0 (2021-03-17)

==> cdk-cloudfront-plus-0.2.6.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.2.6](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.2.5...v0.2.6) (2021-04-06)


### Bug Fixes

* **SO8133:** fix global-data-ingestion demo code ([#67](https://github.com/pahudnet/cdk-cloudfront-plus/issues/67)) ([025a3d0](https://github.com/pahudnet/cdk-cloudfront-plus/commit/025a3d0b0aea723587a9eb0dba88db0ec491b1b4))

### [0.2.5](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.2.4...v0.2.5) (2021-04-06)


### Bug Fixes

* normalize query string class id in integ default ([#66](https://github.com/pahudnet/cdk-cloudfront-plus/issues/66)) ([e907836](https://github.com/pahudnet/cdk-cloudfront-plus/commit/e9078362db97934d2b27a9a8d6e867b007180b8d))

### [0.2.4](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.2.3...v0.2.4) (2021-04-06)


### Bug Fixes

* Normalize query string class id in integ default ([#65](https://github.com/pahudnet/cdk-cloudfront-plus/issues/65)) ([765bd26](https://github.com/pahudnet/cdk-cloudfront-plus/commit/765bd2667e066e8cabd637cfc495edee5013da26))

### [0.2.3](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.2.2...v0.2.3) (2021-04-06)


### Features

* **SO8112:** normalize-query-string ([#64](https://github.com/pahudnet/cdk-cloudfront-plus/issues/64)) ([92c3d90](https://github.com/pahudnet/cdk-cloudfront-plus/commit/92c3d907e72bb30ea5f81a724723e99a6c012e3e))

### [0.2.2](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.2.1...v0.2.2) (2021-04-06)

### [0.2.1](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.35...v0.2.1) (2021-04-06)

## [0.2.0](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.35...v0.2.0) (2021-04-05)

### [0.1.35](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.34...v0.1.35) (2021-04-05)

### [0.1.34](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.33...v0.1.34) (2021-04-05)


### Features

* **ext): OAuth2 Authentication (Authorization Code Grant:** init ([#59](https://github.com/pahudnet/cdk-cloudfront-plus/issues/59)) ([6d5e440](https://github.com/pahudnet/cdk-cloudfront-plus/commit/6d5e44042dc864a138e943224db9e40c1fee7c19)), closes [#17](https://github.com/pahudnet/cdk-cloudfront-plus/issues/17)

### [0.1.33](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.32...v0.1.33) (2021-04-05)

### [0.1.32](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.31...v0.1.32) (2021-04-05)


### Features

* so8120 multiple origin ip retry ([#58](https://github.com/pahudnet/cdk-cloudfront-plus/issues/58)) ([ceb9bfc](https://github.com/pahudnet/cdk-cloudfront-plus/commit/ceb9bfcf8392d2964867f6c7d745154d180f140a))

### [0.1.31](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.30...v0.1.31) (2021-04-05)

### [0.1.30](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.29...v0.1.30) (2021-04-05)

### [0.1.29](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.28...v0.1.29) (2021-04-04)

### [0.1.28](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.27...v0.1.28) (2021-04-04)


### Features

* **SO8118:** Access Origin by Geolocation ([#52](https://github.com/pahudnet/cdk-cloudfront-plus/issues/52)) ([7eba0e9](https://github.com/pahudnet/cdk-cloudfront-plus/commit/7eba0e939a438b9a0066d4bea65ea00229f00849))

### [0.1.27](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.26...v0.1.27) (2021-04-04)

### [0.1.26](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.25...v0.1.26) (2021-04-03)


### Features

* **extension:** redirect by geolocation  ([#50](https://github.com/pahudnet/cdk-cloudfront-plus/issues/50)) ([012f591](https://github.com/pahudnet/cdk-cloudfront-plus/commit/012f59110be8f450e4b432f607cf49580b8e79f5)), closes [#11](https://github.com/pahudnet/cdk-cloudfront-plus/issues/11)

### [0.1.25](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.24...v0.1.25) (2021-04-03)

### [0.1.24](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.23...v0.1.24) (2021-04-03)


### Bug Fixes

* fix wrong path ([#48](https://github.com/pahudnet/cdk-cloudfront-plus/issues/48)) ([fcd3da3](https://github.com/pahudnet/cdk-cloudfront-plus/commit/fcd3da3cc4b5186ef0f5ea41281513857a3bd5ef))

### [0.1.23](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.22...v0.1.23) (2021-04-03)


### Features

* **ext:** new extension - Redirect to custom error page ([#46](https://github.com/pahudnet/cdk-cloudfront-plus/issues/46)) ([14ffc56](https://github.com/pahudnet/cdk-cloudfront-plus/commit/14ffc564f75900fb7596383d550351ebfd08ba1e))

### [0.1.22](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.21...v0.1.22) (2021-04-03)

### [0.1.21](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.20...v0.1.21) (2021-04-02)

### [0.1.20](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.19...v0.1.20) (2021-04-02)

### [0.1.19](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.18...v0.1.19) (2021-04-01)

### [0.1.18](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.17...v0.1.18) (2021-04-01)

### [0.1.17](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.16...v0.1.17) (2021-04-01)


### Features

* **ext:** new extension - Select origin by viewer country  ([#39](https://github.com/pahudnet/cdk-cloudfront-plus/issues/39)) ([b1b0efd](https://github.com/pahudnet/cdk-cloudfront-plus/commit/b1b0efdfc2b7a5580ffb35fee65ba74008c2bc99))

### [0.1.16](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.15...v0.1.16) (2021-04-01)


### Features

* **extension:** use lambda nodejs replace lambda function  ([#38](https://github.com/pahudnet/cdk-cloudfront-plus/issues/38)) ([b14c745](https://github.com/pahudnet/cdk-cloudfront-plus/commit/b14c74583803e343a8a57cc322b09b24a155acca)), closes [#37](https://github.com/pahudnet/cdk-cloudfront-plus/issues/37)

### [0.1.15](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.14...v0.1.15) (2021-03-31)


### Bug Fixes

* remove src rewrite uri demo.ts ([#35](https://github.com/pahudnet/cdk-cloudfront-plus/issues/35)) ([ab591e7](https://github.com/pahudnet/cdk-cloudfront-plus/commit/ab591e78378406ea278b44943c6271f847c22dca))

### [0.1.14](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.13...v0.1.14) (2021-03-31)

### [0.1.13](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.12...v0.1.13) (2021-03-31)

### [0.1.12](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.11...v0.1.12) (2021-03-30)

### [0.1.11](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.10...v0.1.11) (2021-03-30)


### Features

* add SimpleLambdaEdge extension ([#29](https://github.com/pahudnet/cdk-cloudfront-plus/issues/29)) ([f75f814](https://github.com/pahudnet/cdk-cloudfront-plus/commit/f75f814ed1eba44221ae8545b5350a5f8e9c1a08))

### [0.1.10](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.9...v0.1.10) (2021-03-29)

### [0.1.9](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.8...v0.1.9) (2021-03-29)

### [0.1.8](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.7...v0.1.8) (2021-03-29)

### [0.1.7](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.6...v0.1.7) (2021-03-29)

### [0.1.6](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.5...v0.1.6) (2021-03-29)


### Features

* **extension:** default directory indexes in amazon s3 backed amazon cloudfront origins ([#21](https://github.com/pahudnet/cdk-cloudfront-plus/issues/21)) ([a820391](https://github.com/pahudnet/cdk-cloudfront-plus/commit/a820391383fe0e0336c299b83476f2d30ece2820)), closes [#9](https://github.com/pahudnet/cdk-cloudfront-plus/issues/9)

### [0.1.5](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.4...v0.1.5) (2021-03-28)


### Features

* add-custom-props ([#20](https://github.com/pahudnet/cdk-cloudfront-plus/issues/20)) ([c2915c6](https://github.com/pahudnet/cdk-cloudfront-plus/commit/c2915c6a80655b4fb3685eb45ad07396f4d56d74))

### [0.1.4](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.3...v0.1.4) (2021-03-26)

### [0.1.3](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.2...v0.1.3) (2021-03-22)


### Features

* add security headers extension ([85c5a52](https://github.com/pahudnet/cdk-cloudfront-plus/commit/85c5a52a6dfd4c5a6fac4e480cab251e8e5ac4c6))
* support AntiHotlinking extension ([3bf98d8](https://github.com/pahudnet/cdk-cloudfront-plus/commit/3bf98d8ae42044edb8429fc12ff31e91606cf96e))
* support AntiHotlinking extension ([#2](https://github.com/pahudnet/cdk-cloudfront-plus/issues/2)) ([5d68320](https://github.com/pahudnet/cdk-cloudfront-plus/commit/5d6832019636bc03541b086c4808ea0a3737a603))

### [0.1.2](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.1...v0.1.2) (2021-03-17)

### [0.1.1](https://github.com/pahudnet/cdk-cloudfront-plus/compare/v0.1.0...v0.1.1) (2021-03-17)

## 0.1.0 (2021-03-17)
